#ifndef PROCESSDIALOG_H
#define PROCESSDIALOG_H

#include <QDialog>
#include <QProcess>

class configReader;
class writeWindow;

namespace Ui {
    class processDialog;
}

class processDialog : public QDialog
{
    Q_OBJECT

public:
    explicit processDialog(QWidget *parent = 0);
    ~processDialog();

    void gconfStart();

public slots:
    void gconfWrite();
    void gconfFinished();

private:
    Ui::processDialog *ui;
    configReader *procParent;
    writeWindow* writeWin;

    QProcess gconfProcess;
};

#endif // PROCESSDIALOG_H
